#line 2 "bisonflex/cmdoptions.yy.cpp"

#line 4 "bisonflex/cmdoptions.yy.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
    /* The c++ scanner is a mess. The FlexLexer.h header file relies on the
     * following macro. This is required in order to pass the c++-multiple-scanners
     * test in the regression suite. We get reports that it breaks inheritance.
     * We will address this in a future release of flex, or omit the C++ scanner
     * altogether.
     */
    #define yyFlexLexer cmdoptionsFlexLexer
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

/* %endif */

/* %if-c++-only */
/* begin standard C++ headers. */
#include <iostream> 
#include <errno.h>
#include <cstdlib>
#include <cstring>
/* end standard C++ headers. */
/* %endif */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* %not-for-header */

/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
/* %endif */

/* %if-c++-only */
	std::istream* yy_input_file;
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %if-not-reentrant */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */
/* %if-not-reentrant */
/* %not-for-header */

/* %ok-for-header */

/* %endif */
/* %endif */

void *cmdoptionsalloc (yy_size_t  );
void *cmdoptionsrealloc (void *,yy_size_t  );
void cmdoptionsfree (void *  );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG

typedef unsigned char YY_CHAR;

#define yytext_ptr yytext

#include"../win_include/FlexLexer.h"

int yyFlexLexer::yywrap() { return 1; }
int yyFlexLexer::yylex()
	{
	LexerError( "yyFlexLexer::yylex invoked but %option yyclass used" );
	return 0;
	}

#define YY_DECL int FlexScanner::yylex()

/* %if-c-only Standard (non-C++) definition */
/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;

/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 201
#define YY_END_OF_BUFFER 202
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[1140] =
    {   0,
        0,    0,  202,  200,  198,  199,  196,  200,   37,  195,
      195,  196,  194,  194,   36,  194,  195,  195,  195,  195,
      194,  194,  194,  194,  194,  194,  195,  195,    7,  195,
      195,  195,  195,  100,  101,  195,  195,  195,  195,  195,
      102,  195,  195,  198,  199,  196,    0,    0,  195,  195,
      195,  195,  195,  195,  195,  195,   93,  195,  195,  195,
        6,    8,   78,  195,  195,    9,  195,    1,  196,  194,
      195,    0,  195,  195,  195,  194,   84,  194,  195,  195,
      195,  194,   80,  195,  195,  195,  195,  195,  194,  195,
      195,  194,  194,  194,  195,  195,  195,  194,  195,  195,

      195,  195,  195,  195,  195,  134,   82,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
       10,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  197,    0,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,    0,    2,
      196,    3,    0,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,   31,  195,  195,  195,

      195,  195,  194,  195,  195,  195,  195,  195,  195,  194,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,   81,  195,  195,  195,  195,  195,  195,
       62,  195,  112,   30,  195,  195,  195,  195,   11,  195,
      195,  195,  195,  195,  195,  195,  191,   55,   83,  155,
       40,  195,  195,  195,  195,  195,  195,  195,  195,  195,
       56,  195,  195,  140,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
        0,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,   12,  195,  195,  195,  195,

      195,  195,  195,  195,  195,  195,  195,  195,  195,   22,
       26,  195,  195,  195,  195,   96,   54,  195,  195,  195,
      195,  195,  195,  195,  195,  129,  130,  195,  195,  195,
      195,  195,  122,  195,  195,  195,  195,  195,  195,  195,
      195,  133,   99,   70,  195,  195,  195,  195,   23,  195,
       15,  143,   27,  195,  195,  195,  168,  195,  137,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  121,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  141,  195,  195,  195,  195,  195,

      195,   67,   66,  195,  195,  195,  195,   39,  195,  195,
      195,    5,  195,   94,  195,  195,  195,  195,  195,  195,
      195,  195,  195,   79,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,   20,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,   16,  195,  195,  195,
      195,  195,  195,   59,   21,  195,  195,   13,  195,  195,
      195,  195,  195,  184,   98,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  160,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  186,  195,  195,  195,

      195,  195,   17,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,   38,  195,  195,  195,  195,  195,
      195,    4,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,   28,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  180,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  142,
       74,  105,  195,  195,  195,  166,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,

      195,  195,  195,  195,  195,  195,  144,  195,  195,  117,
       69,  195,  195,   68,  195,  195,  195,  195,  195,  195,
      195,  195,  195,   46,  195,  195,  195,  195,  195,  195,
      195,  195,  195,   87,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  109,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,   41,  195,  146,  162,  195,  147,
      195,   44,  167,  195,  195,  195,  148,  195,  149,   35,

      195,  169,  157,  195,  195,  195,  195,  195,  195,  195,
       14,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,   19,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,   24,  195,  195,  195,  195,  195,
      195,  195,  195,   95,  195,  195,  195,  195,  195,  195,
      195,  159,  195,  195,  195,  195,  195,  123,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  125,  195,  195,  195,
       34,  195,  195,  195,  195,  195,  188,  195,  195,  195,
      195,   25,  195,  195,  163,  190,  195,  195,  195,  164,

      195,  195,   18,  195,  195,   45,  195,  195,  195,  195,
      195,  195,  195,   92,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  165,  195,  195,  181,  195,  195,
      195,  195,  195,  195,  152,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,   58,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  139,  138,  195,  195,  195,  195,  195,
       77,  195,   72,  176,  195,  195,   71,  113,  195,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,   90,  195,  145,  195,  195,

      178,  195,  127,  195,  195,   42,  153,  195,  195,  132,
      195,  195,  195,  195,   60,   61,  195,  195,  154,  195,
      195,  195,  195,  195,  193,  195,   75,  136,  115,  195,
      195,  195,  195,  195,  195,  192,  195,  195,  195,   43,
      195,  195,  118,  195,  195,  195,  195,  195,  195,  195,
      195,  195,  195,  195,   63,  195,  195,  195,  195,  195,
      195,   86,  195,  177,  195,  185,  128,  172,  187,  195,
      195,  195,  195,  195,  195,  195,  195,  195,  171,  195,
      195,  195,  195,  195,  195,  124,  108,  195,  195,  179,
      195,  195,  195,  195,  195,  195,  195,  195,  195,  195,

      195,  195,  195,  195,  195,   91,   65,  195,  195,  195,
      195,  126,  195,  195,  195,  195,  189,  195,  195,  103,
      195,  195,  195,  195,  195,  195,  195,  195,  158,  195,
      195,  195,  195,   76,  107,  195,  195,  195,  195,   48,
       49,  195,  195,  195,  195,   89,  195,  195,  195,   64,
      195,  195,  131,  195,  195,  195,  183,  195,  195,  195,
      195,  110,  195,  195,   57,  195,  195,  195,  195,  195,
      195,  195,  195,  195,  195,  195,   53,  195,  195,  195,
      195,  156,  195,  195,  111,  195,  195,  195,  195,  195,
      195,  106,  195,  195,  195,   73,  195,   33,   32,  195,

      195,  195,   47,  195,  195,  195,  173,  195,   97,  116,
      175,  104,  151,  195,  161,  195,  195,  195,   85,   88,
       50,  195,  195,  195,  195,  195,  195,  119,  195,  195,
       51,  120,  195,  170,  114,   52,   29,  174,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    5,    5,    5,    5,    1,    5,
        5,    7,    5,    8,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   18,   19,   20,   21,    1,    1,
       22,    1,    1,    5,   23,   24,   25,   26,   26,   26,
       27,   28,   27,   27,   29,   27,   30,   27,   27,   27,
       27,   27,   31,   27,   27,   27,   27,   32,   27,   27,
        1,   33,    1,    5,   34,    1,   35,   36,   37,   38,

       39,   40,   41,   42,   43,   44,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   57,   58,
       59,   60,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[61] =
    {   0,
        1,    1,    1,    2,    3,    4,    1,    5,    6,    6,
        3,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        1,    1,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    3,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6
    } ;

static yyconst flex_int16_t yy_base[1146] =
    {   0,
        0,    0, 1369, 1370,   59, 1365,    0,   60,    0,   90,
      116,   55,  165,   53, 1370,  154, 1346,   60,   47,  139,
      174,  195,  166,  175,  214,  207,  132,  224,  226,  153,
      240,  197,  234,  255,  292,  231,  269,  257,  261,  178,
       61,   46,  189,  159, 1363,    0, 1359,   91,    0,    0,
       32, 1321,  201,   43, 1320, 1323, 1322, 1313,  249, 1310,
      166,  245, 1319,  242, 1318,    0, 1297, 1370,  347,  227,
      358,  291, 1332, 1295, 1318,  268,  272,  275, 1309, 1314,
     1296,  285,  224,  316, 1300, 1299, 1308,  308,  353, 1311,
      271,  309,  308,  304,  328, 1293, 1307,  354, 1297, 1301,

     1305, 1292, 1304, 1282, 1302,    0, 1282, 1300,  127, 1275,
     1280, 1291, 1278,  367, 1277, 1275, 1281, 1279, 1286, 1285,
        0, 1270, 1269, 1283, 1273,  353, 1268, 1272, 1264, 1279,
     1269,  355, 1270,  364, 1269, 1273,  365, 1277, 1274,  352,
      374, 1265, 1274, 1261, 1261,  266, 1256, 1265, 1265, 1251,
     1250, 1251, 1252, 1370,  396, 1262, 1244, 1257, 1260,  379,
     1240,  380, 1248, 1245, 1246, 1256, 1249, 1248,  386, 1234,
     1248,  342, 1237, 1250, 1247,  377, 1231, 1234, 1278, 1370,
      429,    0,    0, 1255, 1267, 1226, 1240, 1231, 1234, 1232,
     1231, 1237, 1226, 1227, 1235, 1234,    0, 1230, 1212, 1228,

     1205, 1224,  384, 1227, 1207, 1223, 1213, 1208, 1211,  395,
     1203, 1219, 1202, 1204, 1213, 1208,  247, 1215, 1203, 1209,
     1209, 1207, 1208,    0, 1203, 1194, 1188,  412, 1188, 1205,
        0, 1201,    0,    0, 1203, 1198, 1200, 1180, 1181, 1190,
     1198, 1179, 1191, 1184, 1185,  405, 1193,    0,    0,    0,
        0, 1192, 1185, 1184, 1170, 1185, 1181, 1186, 1181, 1179,
        0, 1162, 1160,    0, 1163,  385, 1171, 1173,  391, 1176,
     1165, 1173, 1156, 1169, 1173, 1154,  402, 1157, 1170, 1152,
     1196, 1159, 1158, 1165, 1143, 1151, 1146, 1142, 1158, 1141,
     1146, 1152, 1140, 1148, 1153,    0, 1132, 1150, 1151, 1132,

     1138, 1139, 1144, 1142, 1124, 1125, 1134, 1133, 1124,    0,
        0, 1120, 1131, 1133, 1123,    0,  407, 1123, 1130, 1127,
     1125, 1127, 1120,  415, 1119,    0,    0, 1122, 1103, 1118,
     1113, 1125, 1124, 1098, 1121, 1116, 1108, 1094, 1100, 1101,
     1104,    0,    0,    0, 1115, 1096, 1108, 1109,    0, 1106,
        0,    0,    0, 1092, 1104, 1105,    0, 1099,    0, 1091,
     1086, 1099, 1088, 1082, 1089, 1082, 1098, 1085, 1085, 1082,
     1086, 1081, 1090, 1069, 1082, 1081, 1084, 1079,  407,    0,
     1069, 1068, 1080, 1064, 1074, 1073, 1061, 1071, 1068, 1058,
     1062, 1055, 1070, 1054,    0,  416, 1062, 1066, 1070, 1061,

     1056, 1055,    0, 1062, 1058, 1058, 1064, 1063, 1057, 1049,
     1035,    0, 1041,    0, 1053, 1054, 1036, 1040, 1034, 1041,
     1051, 1038, 1045,    0, 1031, 1039, 1027, 1040, 1032, 1053,
     1062, 1017, 1028, 1024, 1025,    0, 1013, 1023, 1031, 1021,
     1015,  426, 1020, 1017, 1026, 1011,    0, 1029, 1014, 1027,
     1009, 1021, 1024, 1048, 1006, 1016, 1004,    0,  999,  993,
     1014, 1015,  997,    0,  995, 1010,  998,  986, 1005,  994,
     1005,  987,  992,  980, 1003,    0,  996, 1001,  989,  980,
      979,  989,  993,  996,  983,  987,  974,  980,  982,  986,
      967,  983,  987,  985,  973,  977,    0,  971,  977,  419,

      966,  962,    0,  953,  970,  976,  971,  950,  962,  959,
      957,  955,  956,  964,    0,  411,  964,  951,  961,  949,
      963,    0,  938,  954,  946,  935,  958,  951,  956,  937,
      950,  947,    0,  928,  936,  961,  970,  943,  943,  946,
      926,  433,  944,  932,  939,    0,  927,  936,  931,  938,
      937,  934,  915,   46,  934,  929,  914,  923,  923,  914,
      913,  928,  907,  917,  914,  909,  903,  903,  901,  920,
      919,    0,  917,  897,  915,    0,  914,  898,  888,  907,
      904,  905,  909,  899,  893,  891,  896,  899,  889,  883,
      896,  888,  890,  893,  893,  880,  881,  889,  879,  887,

      887,  888,  873,  868,  878,  871,    0,  865,  859,  883,
      434,  875,  877,  875,  859,  866,  858,  857,  866,  420,
      874,  853,  852,    0,  869,  850,  853,  843,  862,  859,
      846,  860,  849,  862,  856,  869,  859,  849,  843,  838,
      846,  845,  844,  832,  835,  841,  835,  826,  835,  839,
      841,  824,  830,  841,  813,  801,  806,  800,  797,  159,
      461,  174,  208,  282,  283,  313,  340,  430,  429,  428,
      440,  442,  443,  440,  430,  439,  447,  453,  440,  450,
      444,  448,  443,  455,    0,  447,    0,    0,  461,    0,
      457,    0,    0,  458,  460,  444,    0,  465,    0,    0,

      464,    0,    0,  464,  455,  469,  452,  461,  493,  469,
        0,  470,  457,  468,  462,  463,  464,  463,  471,  477,
      483,  476,  481,  475,  479,  484,  490,  477,  487,  493,
      489,  494,  485,  478,    0,  485,  487,  480,  500,  499,
      481,  492,  484,    0,  505,  501,  499,  504,  505,  506,
      497,    0,  499,  513,  506,  515,  508,    0,  504,  534,
      540,  519,  501,  508,  510,  500,  520,  527,  521,  511,
      516,  519,  527,  519,  529,  531,    0,  533,  536,  530,
        0,  535,  526,  536,  541,  541,    0,  542,  536,  530,
      527,    0,  543,  544,    0,    0,  546,  529,  532,    0,

      574,  551,    0,  546,  547,    0,  555,  556,  538,  545,
      561,  547,  549,    0,  561,  564,  558,  565,  566,  549,
      566,  592,  557,  568,    0,  561,  574,    0,  571,  559,
      564,  570,  577,  562,    0,  564,  565,  580,  581,  571,
      585,  588,  585,  608,  612,  583,  573,  580,  595,    0,
      587,  589,  584,  594,  598,  616,  585,  597,  601,  605,
      603,  595,  604,    0,  610,  587,  605,  604,  593,  596,
      604,  596,    0,    0,  612,  614,    0,    0,  619,  621,
      622,  614,  615,  605,  612,  619,  625,  622,  627,  619,
      628,  625,  614,  615,  631,    0,  634,    0,  620,  620,

        0,  636,    0,  635,  638,    0,    0,  625,  630,    0,
      632,  635,  635,  634,    0,    0,  630,  643,  652,  641,
      647,  654,  651,  656,    0,  640,    0,    0,    0,  648,
      640,  646,  657,  662,  649,    0,  660,  646,  660,    0,
      647,  651,    0,  670,  651,  659,  660,  654,  655,  668,
      677,  677,  674,  669,    0,  666,  677,  682,  664,  678,
      668,    0,  682,    0,  683,    0,    0,    0,    0,  683,
      690,  686,  678,  688,  676,  696,  693,  693,    0,  680,
      675,  681,  677,  698,  703,    0,    0,  701,  683,    0,
      688,  699,  690,  705,  731,  707,  698,  699,  696,  697,

      717,  714,  700,  695,  702,    0,    0,  718,  704,  715,
      720,    0,  722,  712,  722,  726,    0,  727,  726,    0,
      718,  713,  713,  728,  718,  717,  723,  715,    0,  736,
      728,  723,  731,    0,    0,  723,  742,  743,  744,    0,
        0,  734,  729,  743,  733,    0,  748,  734,  742,    0,
      746,  743,    0,  742,  754,  755,    0,  745,  749,  758,
      759,    0,  747,  746,    0,  749,  763,  751,  769,  758,
      762,  768,  769,  759,  763,  772,    0,  760,  761,  779,
      761,    0,  761,  761,    0,  764,  769,  774,  768,  783,
      780,    0,  772,  786,  785,    0,  773,    0,    0,  774,

      779,  777,    0,  792,  791,  798,    0,  791,    0,    0,
        0,    0,    0,  786,    0,  801,  798,  803,    0,    0,
        0,  804,  801,  800,  805,  795,  797,    0,  804,  799,
        0,    0,  808,    0,    0,    0,    0,    0, 1370,  845,
      850,  852,  857,  863,  869
    } ;

static yyconst flex_int16_t yy_def[1146] =
    {   0,
     1139,    1, 1139, 1139, 1139, 1139, 1140, 1141, 1142, 1139,
       10, 1140,   11,   13, 1139,   13,   11,   11,   11,   11,
       13,   13,   13,   13,   13,   13,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11, 1139, 1139, 1140, 1143, 1143, 1142,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11, 1139, 1144,   13,
       11, 1139,   11,   11,   11,   13,   13,   13,   11,   11,
       11,   13,   11,   11,   11,   11,   11,   11,   13,   11,
       11,   13,   13,   13,   11,   11,   11,   13,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11, 1139, 1139,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11, 1145, 1139,
     1144,   71, 1140,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   13,   11,   11,   11,   11,   11,   11,   13,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
     1143,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,    0, 1139,
     1139, 1139, 1139, 1139, 1139
    } ;

static yyconst flex_int16_t yy_nxt[1431] =
    {   0,
        4,    5,    6,    5,    7,    8,    4,    9,   10,   11,
       12,   13,   14,   14,   14,   14,   14,   14,   14,   14,
        4,   15,   16,   16,   16,   16,   17,   18,   19,   17,
       20,   17,    7,   11,   21,   22,   23,   24,   25,   26,
       27,   28,   29,   17,   30,   31,   32,   33,   34,   35,
       17,   36,   37,   38,   39,   40,   41,   42,   17,   43,
       44,   68,   44,   47,   47,   69,   72,   72,   47,   47,
       47,   47,   47,   47,   47,   47,   47,   47,   47,   47,
       72,   72,  161,  156,   50,   74,  157,  654,  152,   73,
      162,  655,   47,   47,   46,  151,  154,   49,   50,   50,

       46,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,  155,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   50,   46,   50,   51,   52,   50,   53,   54,   55,
       56,   57,   58,   50,   50,   59,   50,   60,   61,   62,
       50,   63,   64,   50,   50,   65,   66,   50,   50,   67,
       50,   50,   72,   50,   50,   50,   50,   50,   50,   72,
       44,   50,   44,   50,   50,   50,  226,   50,   50,  227,
      102,   50,   50,   72,   72,   50,   70,   70,   70,   70,
       70,   70,   70,   70,   70,   50,   72,   70,   70,   70,
       70,  110,   75,  759,   72,   72,   71,   50,   72,   70,

       70,   70,   70,   70,   70,   50,   50,   87,   76,   72,
       77,   50,   78,   89,   88,   72,  150,   72,  762,   79,
      170,  171,   71,   50,   90,   80,   50,   72,   81,   91,
       82,   50,   50,  115,   72,  116,   83,   84,   50,  159,
       85,   98,  763,   86,   72,   50,   72,  153,   92,   99,
       93,   72,   50,   94,   72,  160,  100,  193,   50,  101,
       72,   95,  103,  106,   50,   96,  104,  107,  117,  137,
      105,   97,  108,  109,  111,   72,  194,   72,  112,  172,
      175,   72,  118,  138,   50,  342,  113,  167,  114,   72,
      119,  176,  343,  144,  120,  145,  173,  168,  148,   50,

      272,  183,  121,   50,  122,  207,   50,  139,  146,  123,
      124,  125,   72,  149,  140,  147,   50,  208,  141,  187,
      273,  142,  143,  183,  764,   50,  126,  188,  127,   50,
      128,  765,   50,  129,  130,   50,  192,  131,  132,   50,
       50,  133,   50,  134,  135,  210,  136,  179,  179,  180,
      179,  766,  179,  179,  179,  195,  196,  201,  211,  202,
      209,   50,  212,  197,  213,   50,   50,  179,  179,  182,
      182,  182,  182,  182,  182,  182,  182,  182,  301,  302,
      182,  182,  182,  182,   50,   50,  263,  767,  203,  244,
      245,  252,  182,  182,  182,  182,  182,  182,  204,  259,

      216,  232,  255,  264,  246,  205,  281,  233,  265,  253,
       50,   50,  256,  286,  289,   50,  290,  260,  266,  267,
      297,  306,  307,  353,  385,  287,   50,  389,  281,  179,
      179,  180,  179,  298,  179,  179,  179,  386,  328,  369,
      434,   50,  390,  370,  398,  435,  489,  335,  442,  179,
      179,  505,   50,  506,  399,  602,  490,  443,  371,  617,
      444,  618,  547,  548,  354,  549,  642,  709,  768,  719,
      445,  769,  643,  603,  720,  760,  770,  761,  771,  772,
      773,  710,  774,  775,  776,  777,  778,  779,  780,  781,
      782,  783,  784,  785,  786,  787,  788,  789,  790,  791,

      792,  793,  794,  795,  796,  797,  798,  799,  800,  801,
      802,  803,  804,  805,  806,  807,  808,  809,  810,  811,
      812,  813,  814,  815,  816,  817,  818,  819,  820,  821,
      822,  823,  824,  825,  826,  827,  828,  829,  830,  831,
      832,  833,  834,  835,  836,  837,  838,  839,  840,  841,
      842,  843,  844,  845,  846,  847,  848,  849,  850,  851,
      852,  853,  854,  855,  856,  857,  858,  859,  860,  861,
      862,  863,  864,  865,  866,  867,  868,  869,  870,  871,
      872,  873,  874,  875,  876,  877,  878,  879,  880,  881,
      882,  883,  884,  885,  886,  887,  888,  889,  890,  891,

      892,  893,  894,  895,  896,  897,  898,  899,  900,  901,
      902,  903,  904,  905,  906,  907,  908,  909,  910,  911,
      912,  913,  914,  915,  916,  917,  918,  919,  920,  921,
      922,  924,  925,  923,  926,  927,  928,  929,  930,  931,
      932,  933,  934,  935,  936,  937,  938,  939,  940,  941,
      942,  943,  944,  945,  946,  947,  948,  949,  950,  951,
      952,  954,  955,  953,  956,  957,  958,  959,  960,  961,
      962,  963,  964,  965,  966,  967,  968,  969,  970,  971,
      972,  973,  974,  975,  976,  977,  978,  979,  980,  981,
      982,  983,  984,  985,  986,  987,  988,  989,  990,  991,

      992,  993,  994,  995,  996,  997,  998,  999, 1000, 1001,
     1002, 1003, 1004, 1005, 1006, 1007, 1008, 1009, 1010, 1011,
     1012, 1013, 1015, 1016, 1017, 1014, 1018, 1019, 1020, 1021,
     1022, 1023, 1024, 1025, 1026, 1027, 1028, 1029, 1030, 1031,
     1032, 1033, 1034, 1035, 1036, 1037, 1038, 1039, 1040, 1041,
     1042, 1043, 1044, 1045, 1046, 1047, 1048, 1049, 1050, 1051,
     1052, 1053, 1054, 1055, 1056, 1057, 1058, 1059, 1060, 1061,
     1062, 1063, 1064, 1065, 1066, 1067, 1068, 1069, 1070, 1071,
     1072, 1073, 1074, 1075, 1076, 1077, 1078, 1079, 1080, 1081,
     1082, 1083, 1084, 1085, 1086, 1087, 1088, 1089, 1090, 1091,

     1092, 1093, 1094, 1095, 1096, 1097, 1098, 1099, 1100, 1101,
     1102, 1103, 1104, 1105, 1106, 1107, 1108, 1109, 1110, 1111,
     1112, 1113, 1114, 1115, 1116, 1117, 1118, 1119, 1120, 1121,
     1122, 1123, 1124, 1125, 1126, 1127, 1128, 1129, 1130, 1131,
     1132, 1133, 1134, 1135, 1136, 1137, 1138,   46,  758,  757,
       46,   48,   48,  756,  755,   48,   49,   49,   47,   47,
       47,  754,   47,  181,  181,  181,  181,  181,  181,  179,
      179,  179,  179,  179,  179,  753,  752,  751,  750,  749,
      748,  747,  746,  745,  744,  743,  742,  741,  740,  739,
      738,  737,  736,  735,  734,  733,  732,  731,  730,  729,

      728,  727,  726,  725,  724,  723,  722,  721,  718,  717,
      716,  715,  714,  713,  712,  711,  708,  707,  706,  705,
      704,  703,  702,  701,  700,  699,  698,  697,  696,  695,
      694,  693,  692,  691,  690,  689,  688,  687,  686,  685,
      684,  683,  682,  681,  680,  679,  678,  677,  676,  675,
      674,  673,  672,  671,  670,  669,  668,  667,  666,  665,
      664,  663,  662,  661,  660,  659,  658,  657,  656,  653,
      652,  651,  650,  649,  648,  647,  646,  645,  644,  641,
      640,  639,  638,  637,  636,  635,  634,  633,  632,  631,
      630,  629,  628,  627,  626,  625,  624,  623,  622,  621,

      620,  619,  616,  615,  614,  613,  612,  611,  610,  609,
      608,  607,  606,  605,  604,  601,  600,  599,  598,  597,
      596,  595,  594,  593,  592,  591,  590,  589,  588,  587,
      586,  585,  584,  583,  582,  581,  580,  579,  578,  577,
      576,  575,  574,  573,  572,  571,  570,  569,  568,  567,
      566,  565,  564,  563,  562,  561,  560,  559,  558,  557,
      556,  555,  554,  553,  552,  551,  550,  546,  545,  544,
      543,  542,  541,  540,  539,  538,  537,  536,  535,  534,
      533,  532,  531,  530,  529,  528,  527,  526,  525,  524,
      523,  522,  521,  520,  519,  518,  517,  516,  515,  514,

      513,  512,  511,  510,  509,  508,  507,  504,  503,  502,
      501,  500,  499,  498,  497,  496,  495,  494,  493,  492,
      491,  488,  487,  486,  485,  484,  483,  482,  481,  480,
      479,  478,  477,  476,  475,  474,  473,  472,  471,  470,
      469,  468,  467,  466,  465,  464,  463,  462,  461,  460,
      459,  458,  457,  456,  455,  454,  453,  452,  451,  450,
      449,  448,  447,  446,  441,  440,  439,  438,  437,  436,
      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  417,  416,  415,  414,
      413,  412,  411,  410,  409,  408,  407,  406,  405,  404,

      403, 1139,  402,  401,  400,  397,  396,  395,  394,  393,
      392,  391,  388,  387,  384,  383,  382,  381,  380,  379,
      378,  377,  376,  375,  374,  373,  372,  368,  367,  366,
      365,  364,  363,  362,  361,  360,  359,  358,  357,  356,
      355,  352,  351,  350,  349,  348,  347,  346,  345,  344,
      341,  340,  339,  338,  337,  336,  334,  333,  332,  331,
      330,  329,  327,  326,  325,  324,  323,  322,  321,  320,
      319,  318,  317,  316,  315,  314,  313,  312,  311,  310,
      180,  309,  308,  305,  304,  303,  300,  299,  296,  295,
      294,  293,  292,  291,  288,  285,  284,  283,  282,  280,

      279,  278,  277,  276,  275,  274,  271,  270,  269,  268,
      262,  261,  258,  257,  254,  251,  250,  249,  248,  247,
      243,  242,  241,  240,  239,  238,  237,  236,  235,  234,
      231,  230,  229,  228,  225,  224,  223,  222,  221,  220,
      219,  218,  217,  215,  214,  206,  200,  199,  198,  191,
      190,  189,  186,  185,  184,  178,  177,  174,  169,  166,
      165,  164,  163,  158,  154,   45,   72,   45, 1139,    3,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,

     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139
    } ;

static yyconst flex_int16_t yy_chk[1431] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        5,   12,    5,    8,    8,   12,   42,   19,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
       18,   41,   54,   51,   14,   19,   51,  554,   42,   18,
       54,  554,    8,    8,   10,   41,   48,   10,   10,   10,

       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       14,   48,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   10,   10,   10,
       11,   11,   27,   11,   11,   11,   11,   11,   11,   20,
       44,   11,   44,   11,   11,   11,  109,   11,   11,  109,
       27,   11,   11,   30,   16,   11,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   16,   23,   13,   13,   13,
       13,   30,   20,  660,   21,   24,   13,   23,   40,   13,

       13,   13,   13,   13,   13,   21,   24,   23,   21,   43,
       21,   16,   21,   24,   23,   22,   40,   32,  662,   21,
       61,   61,   13,   23,   24,   21,   22,   26,   21,   24,
       22,   21,   24,   32,   25,   32,   22,   22,   26,   53,
       22,   26,  663,   22,   28,   25,   29,   43,   25,   26,
       25,   36,   22,   25,   33,   53,   26,   83,   70,   26,
       31,   25,   28,   29,   26,   25,   28,   29,   33,   36,
       28,   25,   29,   29,   31,   34,   83,   38,   31,   62,
       64,   39,   33,   36,   70,  217,   31,   59,   31,   37,
       34,   64,  217,   38,   34,   38,   62,   59,   39,   76,

      146,   72,   34,   77,   34,   91,   78,   37,   38,   34,
       34,   34,   35,   39,   37,   38,   82,   91,   37,   76,
      146,   37,   37,   72,  664,   76,   35,   78,   35,   77,
       35,  665,   78,   35,   35,   94,   82,   35,   35,   93,
       92,   35,   82,   35,   35,   93,   35,   69,   69,   69,
       69,  666,   69,   69,   69,   84,   84,   88,   94,   88,
       92,   94,   95,   84,   95,   93,   92,   69,   69,   71,
       71,   71,   71,   71,   71,   71,   71,   71,  172,  172,
       71,   71,   71,   71,   89,   98,  140,  667,   89,  126,
      126,  132,   71,   71,   71,   71,   71,   71,   89,  137,

       98,  114,  134,  140,  126,   89,  155,  114,  141,  132,
       89,   98,  134,  160,  162,  203,  162,  137,  141,  141,
      169,  176,  176,  228,  266,  160,  210,  269,  155,  181,
      181,  181,  181,  169,  181,  181,  181,  266,  203,  246,
      317,  203,  269,  246,  277,  317,  379,  210,  324,  181,
      181,  396,  210,  396,  277,  500,  379,  324,  246,  516,
      324,  516,  442,  442,  228,  442,  542,  611,  668,  620,
      324,  669,  542,  500,  620,  661,  670,  661,  671,  672,
      673,  611,  674,  675,  676,  677,  678,  679,  680,  681,
      682,  683,  684,  686,  689,  691,  694,  695,  696,  698,

      701,  704,  705,  706,  707,  708,  709,  710,  712,  713,
      714,  715,  716,  717,  718,  719,  720,  721,  722,  723,
      724,  725,  726,  727,  728,  729,  730,  731,  732,  733,
      734,  736,  737,  738,  739,  740,  741,  742,  743,  745,
      746,  747,  748,  749,  750,  751,  753,  754,  755,  756,
      757,  759,  760,  761,  762,  763,  764,  765,  766,  767,
      768,  769,  770,  771,  772,  773,  774,  775,  776,  778,
      779,  780,  782,  783,  784,  785,  786,  788,  789,  790,
      791,  793,  794,  797,  798,  799,  801,  802,  804,  805,
      807,  808,  809,  810,  811,  812,  813,  815,  816,  817,

      818,  819,  820,  821,  822,  823,  824,  826,  827,  829,
      830,  831,  832,  833,  834,  836,  837,  838,  839,  840,
      841,  842,  843,  844,  845,  846,  847,  848,  849,  851,
      852,  853,  854,  852,  855,  856,  857,  858,  859,  860,
      861,  862,  863,  865,  866,  867,  868,  869,  870,  871,
      872,  875,  876,  879,  880,  881,  882,  883,  884,  885,
      886,  887,  888,  886,  889,  890,  891,  892,  893,  894,
      895,  897,  899,  900,  902,  904,  905,  908,  909,  911,
      912,  913,  914,  917,  918,  919,  920,  921,  922,  923,
      924,  926,  930,  931,  932,  933,  934,  935,  937,  938,

      939,  941,  942,  944,  945,  946,  947,  948,  949,  950,
      951,  952,  953,  954,  956,  957,  958,  959,  960,  961,
      963,  965,  970,  971,  972,  965,  973,  974,  975,  976,
      977,  978,  980,  981,  982,  983,  984,  985,  988,  989,
      991,  992,  993,  994,  995,  996,  997,  998,  999, 1000,
     1001, 1002, 1003, 1004, 1005, 1008, 1009, 1010, 1011, 1013,
     1014, 1015, 1016, 1016, 1018, 1019, 1021, 1022, 1023, 1024,
     1025, 1026, 1027, 1028, 1030, 1031, 1032, 1033, 1036, 1037,
     1038, 1039, 1042, 1043, 1044, 1045, 1047, 1048, 1049, 1051,
     1052, 1054, 1055, 1056, 1058, 1059, 1060, 1061, 1063, 1064,

     1066, 1067, 1068, 1069, 1070, 1071, 1072, 1073, 1074, 1075,
     1076, 1078, 1079, 1080, 1081, 1083, 1084, 1086, 1087, 1088,
     1089, 1090, 1091, 1093, 1094, 1095, 1097, 1100, 1101, 1102,
     1104, 1105, 1106, 1108, 1114, 1116, 1117, 1118, 1122, 1123,
     1124, 1125, 1126, 1127, 1129, 1130, 1133, 1140,  659,  658,
     1140, 1141, 1141,  657,  656, 1141, 1142, 1142, 1143, 1143,
     1143,  655, 1143, 1144, 1144, 1144, 1144, 1144, 1144, 1145,
     1145, 1145, 1145, 1145, 1145,  654,  653,  652,  651,  650,
      649,  648,  647,  646,  645,  644,  643,  642,  641,  640,
      639,  638,  637,  636,  635,  634,  633,  632,  631,  630,

      629,  628,  627,  626,  625,  623,  622,  621,  619,  618,
      617,  616,  615,  614,  613,  612,  610,  609,  608,  606,
      605,  604,  603,  602,  601,  600,  599,  598,  597,  596,
      595,  594,  593,  592,  591,  590,  589,  588,  587,  586,
      585,  584,  583,  582,  581,  580,  579,  578,  577,  575,
      574,  573,  571,  570,  569,  568,  567,  566,  565,  564,
      563,  562,  561,  560,  559,  558,  557,  556,  555,  553,
      552,  551,  550,  549,  548,  547,  545,  544,  543,  541,
      540,  539,  538,  537,  536,  535,  534,  532,  531,  530,
      529,  528,  527,  526,  525,  524,  523,  521,  520,  519,

      518,  517,  514,  513,  512,  511,  510,  509,  508,  507,
      506,  505,  504,  502,  501,  499,  498,  496,  495,  494,
      493,  492,  491,  490,  489,  488,  487,  486,  485,  484,
      483,  482,  481,  480,  479,  478,  477,  475,  474,  473,
      472,  471,  470,  469,  468,  467,  466,  465,  463,  462,
      461,  460,  459,  457,  456,  455,  454,  453,  452,  451,
      450,  449,  448,  446,  445,  444,  443,  441,  440,  439,
      438,  437,  435,  434,  433,  432,  431,  430,  429,  428,
      427,  426,  425,  423,  422,  421,  420,  419,  418,  417,
      416,  415,  413,  411,  410,  409,  408,  407,  406,  405,

      404,  402,  401,  400,  399,  398,  397,  394,  393,  392,
      391,  390,  389,  388,  387,  386,  385,  384,  383,  382,
      381,  378,  377,  376,  375,  374,  373,  372,  371,  370,
      369,  368,  367,  366,  365,  364,  363,  362,  361,  360,
      358,  356,  355,  354,  350,  348,  347,  346,  345,  341,
      340,  339,  338,  337,  336,  335,  334,  333,  332,  331,
      330,  329,  328,  325,  323,  322,  321,  320,  319,  318,
      315,  314,  313,  312,  309,  308,  307,  306,  305,  304,
      303,  302,  301,  300,  299,  298,  297,  295,  294,  293,
      292,  291,  290,  289,  288,  287,  286,  285,  284,  283,

      282,  281,  280,  279,  278,  276,  275,  274,  273,  272,
      271,  270,  268,  267,  265,  263,  262,  260,  259,  258,
      257,  256,  255,  254,  253,  252,  247,  245,  244,  243,
      242,  241,  240,  239,  238,  237,  236,  235,  232,  230,
      229,  227,  226,  225,  223,  222,  221,  220,  219,  218,
      216,  215,  214,  213,  212,  211,  209,  208,  207,  206,
      205,  204,  202,  201,  200,  199,  198,  196,  195,  194,
      193,  192,  191,  190,  189,  188,  187,  186,  185,  184,
      179,  178,  177,  175,  174,  173,  171,  170,  168,  167,
      166,  165,  164,  163,  161,  159,  158,  157,  156,  153,

      152,  151,  150,  149,  148,  147,  145,  144,  143,  142,
      139,  138,  136,  135,  133,  131,  130,  129,  128,  127,
      125,  124,  123,  122,  120,  119,  118,  117,  116,  115,
      113,  112,  111,  110,  108,  107,  105,  104,  103,  102,
      101,  100,   99,   97,   96,   90,   87,   86,   85,   81,
       80,   79,   75,   74,   73,   67,   65,   63,   60,   58,
       57,   56,   55,   52,   47,   45,   17,    6,    3, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,

     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139,
     1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139, 1139
    } ;

static yyconst flex_int16_t yy_rule_linenum[201] =
    {   0,
       43,   44,   46,   49,   50,   51,   52,   53,   55,   56,
       57,   59,   60,   61,   62,   63,   64,   66,   68,   69,
       70,   71,   72,   73,   74,   75,   76,   78,   79,   80,
       81,   83,   84,   85,   86,   88,   89,   90,   91,   92,
       93,   94,   95,   96,   98,   99,  100,  101,  102,  103,
      105,  106,  108,  109,  110,  111,  112,  113,  114,  115,
      116,  117,  119,  120,  121,  123,  124,  125,  126,  127,
      128,  129,  130,  131,  132,  133,  134,  136,  138,  139,
      140,  141,  142,  143,  145,  146,  147,  148,  149,  150,
      151,  152,  154,  155,  156,  157,  158,  159,  160,  161,

      162,  163,  164,  165,  166,  167,  168,  169,  170,  171,
      172,  173,  174,  175,  176,  177,  178,  179,  180,  181,
      182,  183,  184,  185,  186,  188,  189,  190,  191,  192,
      193,  194,  195,  196,  197,  198,  199,  200,  201,  202,
      203,  204,  205,  206,  207,  208,  209,  210,  211,  212,
      213,  214,  215,  216,  217,  218,  219,  220,  221,  222,
      223,  224,  225,  226,  227,  228,  229,  230,  231,  232,
      233,  234,  235,  236,  237,  238,  239,  240,  241,  242,
      243,  244,  245,  246,  247,  248,  249,  250,  251,  252,
      253,  254,  255,  259,  260,  261,  262,  265,  266,  267

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "parser/cmdoptions.l"
/******************************************************************************
* Copyright 2015-2022 Xilinx, Inc.
* Copyright 2022-2023 Advanced Micro Devices, Inc.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
******************************************************************************/
/* This is the lexer/flexer input file, that tokenizes the register initialization file */
/* Run the cmdoptions.y file first through bison to generate the regidit.tab.hpp file, which is included herein */
/* Then run this file through flex to generate the cmdoptions.yy.c source code */
#line 23 "parser/cmdoptions.l"
 #include <stdio.h>
 #include "cmdoptionsscanner.h"
 #include "cmdoptions.tab.hpp"
 typedef CO::BisonParser::token tok;
#line 32 "parser/cmdoptions.l"
     # define YY_USER_ACTION  yylloc->columns (yyleng);
#line 1232 "bisonflex/cmdoptions.yy.cpp"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#include <unistd.h>
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */
/* %if-bison-bridge */
/* %endif */
/* %not-for-header */

/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */

/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */
/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define ECHO LexerOutput( yytext, yyleng )
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
\
/* %if-c++-only C++ definition \ */\
	if ( (result = LexerInput( (char *) buf, max_size )) < 0 ) \
		YY_FATAL_ERROR( "input in flex scanner failed" );
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
/* %endif */
/* %if-c++-only */
#define YY_FATAL_ERROR(msg) LexerError( msg )
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */

/* %ok-for-header */

/* %not-for-header */

/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */
/* %endif */
/* %if-c++-only C++ definition */
#define YY_DECL int yyFlexLexer::yylex()
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	YY_USER_ACTION

/* %not-for-header */

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
/* %% [7.0] user's declarations go here */
#line 35 "parser/cmdoptions.l"



   yylloc->step ();




#line 1398 "bisonflex/cmdoptions.yy.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyin = & std::cin;
/* %endif */

		if ( ! yyout )
/* %if-c-only */
/* %endif */
/* %if-c++-only */
			yyout = & std::cout;
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 1140 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 1139 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				std::cerr << "--scanner backing up\n";
			else if ( yy_act < 201 )
				std::cerr << "--accepting rule at line " << yy_rule_linenum[yy_act] <<
				         "(\"" << yytext << "\")\n";
			else if ( yy_act == 201 )
				std::cerr << "--accepting default rule (\"" << yytext << "\")\n";
			else if ( yy_act == 202 )
				std::cerr << "--(end of buffer or a NUL)\n";
			else
				std::cerr << "--EOF (start condition " << YY_START << ")\n";
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 43 "parser/cmdoptions.l"
{ comment(); }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 44 "parser/cmdoptions.l"
/* ignore */;
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 46 "parser/cmdoptions.l"
yylval->number=strtoul(yytext+2,NULL,16); return tok::HEXVALUE;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 49 "parser/cmdoptions.l"
return tok::_IMAGE;
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 50 "parser/cmdoptions.l"
return tok::_FILL;
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 51 "parser/cmdoptions.l"
return tok::_O_TOK;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 52 "parser/cmdoptions.l"
return tok::I;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 53 "parser/cmdoptions.l"
return tok::_P_TOK;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 55 "parser/cmdoptions.l"
return tok::_W;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 56 "parser/cmdoptions.l"
return tok::ON;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 57 "parser/cmdoptions.l"
return tok::OFF;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 59 "parser/cmdoptions.l"
return tok::_LOG;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 60 "parser/cmdoptions.l"
return tok::ERROR;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 61 "parser/cmdoptions.l"
return tok::WARNING;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 62 "parser/cmdoptions.l"
return tok::INFO;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 63 "parser/cmdoptions.l"
return tok::DEBUG;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 64 "parser/cmdoptions.l"
return tok::TRACE;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 66 "parser/cmdoptions.l"
return tok::_BIF_HELP;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 68 "parser/cmdoptions.l"
return tok::_ENCRYPT;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 69 "parser/cmdoptions.l"
return tok::BBRAM;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 70 "parser/cmdoptions.l"
return tok::EFUSE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 71 "parser/cmdoptions.l"
return tok::HMAC;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 72 "parser/cmdoptions.l"
return tok::HMAC;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 73 "parser/cmdoptions.l"
return tok::STARTCBC;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 74 "parser/cmdoptions.l"
return tok::STARTCBC;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 75 "parser/cmdoptions.l"
return tok::KEY0;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 76 "parser/cmdoptions.l"
return tok::KEY0;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 78 "parser/cmdoptions.l"
return tok::_SPLIT;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 79 "parser/cmdoptions.l"
return tok::_PROCESS_BITSTREAM;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 80 "parser/cmdoptions.l"
return tok::MCS;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 81 "parser/cmdoptions.l"
return tok::BIN;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 83 "parser/cmdoptions.l"
return tok::_DUAL_QSPI_MODE;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 84 "parser/cmdoptions.l"
return tok::_DUAL_OSPI_MODE;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 85 "parser/cmdoptions.l"
return tok::PARALLEL;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 86 "parser/cmdoptions.l"
return tok::STACKED;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 88 "parser/cmdoptions.l"
return tok::EQUALS;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 89 "parser/cmdoptions.l"
return tok::COMMA;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 90 "parser/cmdoptions.l"
return tok::_DEBUG_TOK;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 91 "parser/cmdoptions.l"
return tok::_DUMP;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 92 "parser/cmdoptions.l"
return tok::DUMP_PLM;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 93 "parser/cmdoptions.l"
return tok::DUMP_PMC_CDO;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 94 "parser/cmdoptions.l"
return tok::DUMP_BOOT_FILES;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 95 "parser/cmdoptions.l"
return tok::DUMP_SLAVE_PDIS;
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 96 "parser/cmdoptions.l"
return tok::DUMP_PUF_PDI;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "parser/cmdoptions.l"
return tok::_DUMP_DIR;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "parser/cmdoptions.l"
return tok::_LEGACY;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "parser/cmdoptions.l"
return tok::_PADIMAGEHEADER;
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "parser/cmdoptions.l"
return tok::_EFUSEPPKBITS;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "parser/cmdoptions.l"
return tok::_EFUSEPUFBITS;
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "parser/cmdoptions.l"
return tok::_GENERATE_HASHES;
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 105 "parser/cmdoptions.l"
return tok::_SECUREDEBUG;
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 106 "parser/cmdoptions.l"
return tok::_AUTHJTAG;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 108 "parser/cmdoptions.l"
return tok::_GENERATE_KEYS;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 109 "parser/cmdoptions.l"
return tok::AUTH;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 110 "parser/cmdoptions.l"
return tok::PEM;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 111 "parser/cmdoptions.l"
return tok::RSA;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 112 "parser/cmdoptions.l"
return tok::GREY;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 113 "parser/cmdoptions.l"
return tok::METAL;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 114 "parser/cmdoptions.l"
return tok::ECDSA;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 115 "parser/cmdoptions.l"
return tok::ECDSA;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 116 "parser/cmdoptions.l"
return tok::ECDSAP521;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 117 "parser/cmdoptions.l"
return tok::LMS;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 119 "parser/cmdoptions.l"
return tok::_NONBOOTING;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 120 "parser/cmdoptions.l"
return tok::_SPKSIGNATURE;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 121 "parser/cmdoptions.l"
return tok::_PACKAGENAME;
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 123 "parser/cmdoptions.l"
return tok::_ARCH;
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 124 "parser/cmdoptions.l"
return tok::ZYNQ;
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 125 "parser/cmdoptions.l"
return tok::ZYNQMP;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 126 "parser/cmdoptions.l"
return tok::VERSAL;
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 127 "parser/cmdoptions.l"
return tok::FPGA;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 128 "parser/cmdoptions.l"
return tok::VERSALNET;
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 129 "parser/cmdoptions.l"
return tok::TELLURIDE;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 130 "parser/cmdoptions.l"
return tok::VERSAL_2VE_2VM;
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 131 "parser/cmdoptions.l"
return tok::LASSEN;
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 132 "parser/cmdoptions.l"
return tok::LASSEN_DL9;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 133 "parser/cmdoptions.l"
return tok::SPARTANUP;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 134 "parser/cmdoptions.l"
return tok::SPARTANUP;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 136 "parser/cmdoptions.l"
return tok::_R;
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 138 "parser/cmdoptions.l"
return tok::_READ;
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 139 "parser/cmdoptions.l"
return tok::READ_BH;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 140 "parser/cmdoptions.l"
return tok::READ_IHT;
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 141 "parser/cmdoptions.l"
return tok::READ_IH;
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 142 "parser/cmdoptions.l"
return tok::READ_PHT;
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 143 "parser/cmdoptions.l"
return tok::READ_AC;
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 145 "parser/cmdoptions.l"
return tok::_AUTH_OPTIMIZATION;
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 146 "parser/cmdoptions.l"
return tok::_VERIFYKDF;
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 147 "parser/cmdoptions.l"
return tok::_VERIFY;
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 148 "parser/cmdoptions.l"
return tok::_ZYNQMPENCRDUMP;
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 149 "parser/cmdoptions.l"
return tok::_NOAUTHBLOCKS;
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 150 "parser/cmdoptions.l"
return tok::_ZYNQMPES1;
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 151 "parser/cmdoptions.l"
return tok::_OVERLAYCDO;
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 152 "parser/cmdoptions.l"
return tok::_OUT_TYPE;
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 154 "parser/cmdoptions.l"
return tok::_H;
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 155 "parser/cmdoptions.l"
return tok::_H;
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 156 "parser/cmdoptions.l"
return tok::HBIFHELP;
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 157 "parser/cmdoptions.l"
return tok::HARCH;
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 158 "parser/cmdoptions.l"
return tok::HAUTHOPT;
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 159 "parser/cmdoptions.l"
return tok::HIMAGE;
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 160 "parser/cmdoptions.l"
return tok::HFILL;
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 161 "parser/cmdoptions.l"
return tok::HO;
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 162 "parser/cmdoptions.l"
return tok::HP;
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 163 "parser/cmdoptions.l"
return tok::HW;
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 164 "parser/cmdoptions.l"
return tok::HEFUSEPPKBITS;
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 165 "parser/cmdoptions.l"
return tok::HGENHASHES;
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 166 "parser/cmdoptions.l"
return tok::HLEGACY;
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 167 "parser/cmdoptions.l"
return tok::HPADHDR;
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 168 "parser/cmdoptions.l"
return tok::H_SPKSIGN;
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 169 "parser/cmdoptions.l"
return tok::HPACKAGE;
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 170 "parser/cmdoptions.l"
return tok::HENCRYPT;
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 171 "parser/cmdoptions.l"
return tok::HGENKEYS;
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 172 "parser/cmdoptions.l"
return tok::HDQSPI;
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 173 "parser/cmdoptions.l"
return tok::HLOG;
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 174 "parser/cmdoptions.l"
return tok::HZYNQMPES1;
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 175 "parser/cmdoptions.l"
return tok::HPROCESSBIT;
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 176 "parser/cmdoptions.l"
return tok::HNONBOOTING;
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 177 "parser/cmdoptions.l"
return tok::HENCRDUMP;
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 178 "parser/cmdoptions.l"
return tok::HVERIFY;
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 179 "parser/cmdoptions.l"
return tok::HVERIFYKDF;
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 180 "parser/cmdoptions.l"
return tok::HSECUREDEBUG;
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 181 "parser/cmdoptions.l"
return tok::HSECUREDEBUG;
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 182 "parser/cmdoptions.l"
return tok::HREAD;
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 183 "parser/cmdoptions.l"
return tok::HDUMP;
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 184 "parser/cmdoptions.l"
return tok::HDUMPDIR;
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 185 "parser/cmdoptions.l"
return tok::HOVLCDO;
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 186 "parser/cmdoptions.l"
return tok::HOUTTYPE;
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 188 "parser/cmdoptions.l"
return tok::H_BIF_AARCH32;
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 189 "parser/cmdoptions.l"
return tok::H_BIF_BIGENDIAN;
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 190 "parser/cmdoptions.l"
return tok::H_BIF_BOOTCONFIG;
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 191 "parser/cmdoptions.l"
return tok::H_BIF_COPY;
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 192 "parser/cmdoptions.l"
return tok::H_BIF_CORE;
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 193 "parser/cmdoptions.l"
return tok::H_BIF_DELAY_HANDOFF;
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 194 "parser/cmdoptions.l"
return tok::H_BIF_DELAY_LOAD;
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 195 "parser/cmdoptions.l"
return tok::H_BIF_FILE;
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 196 "parser/cmdoptions.l"
return tok::H_BIF_ID;
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 197 "parser/cmdoptions.l"
return tok::H_BIF_IMAGE;
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 198 "parser/cmdoptions.l"
return tok::H_BIF_METAHDR;
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 199 "parser/cmdoptions.l"
return tok::H_BIF_NAME;
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 200 "parser/cmdoptions.l"
return tok::H_BIF_PARTITION;
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 201 "parser/cmdoptions.l"
return tok::H_BIF_PARENTID;
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 202 "parser/cmdoptions.l"
return tok::H_BIF_SLR;
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 203 "parser/cmdoptions.l"
return tok::H_BIF_TYPE;
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 204 "parser/cmdoptions.l"
return tok::H_BIF_KEYSRC;
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 205 "parser/cmdoptions.l"
return tok::H_BIF_INIT;
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 206 "parser/cmdoptions.l"
return tok::H_BIF_UDFBH;
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 207 "parser/cmdoptions.l"
return tok::H_BIF_AES;
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 208 "parser/cmdoptions.l"
return tok::H_BIF_PPK;
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 209 "parser/cmdoptions.l"
return tok::H_BIF_PSK;
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 210 "parser/cmdoptions.l"
return tok::H_BIF_SPK;
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 211 "parser/cmdoptions.l"
return tok::H_BIF_SSK;
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 212 "parser/cmdoptions.l"
return tok::H_BIF_SPKSIGN;
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 213 "parser/cmdoptions.l"
return tok::H_BIF_HDRSIGN;
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 214 "parser/cmdoptions.l"
return tok::H_BIF_BOOTIMAGE;
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 215 "parser/cmdoptions.l"
return tok::H_BIF_BL;
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 216 "parser/cmdoptions.l"
return tok::H_BIF_ENCR;
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 217 "parser/cmdoptions.l"
return tok::H_BIF_PID;
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 218 "parser/cmdoptions.l"
return tok::H_BIF_AUTH;
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 219 "parser/cmdoptions.l"
return tok::H_BIF_TCMBOOT;
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 220 "parser/cmdoptions.l"
return tok::H_BIF_OPTIONALDATA;
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 221 "parser/cmdoptions.l"
return tok::H_BIF_CHKSM;
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 222 "parser/cmdoptions.l"
return tok::H_BIF_POWNER;
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 223 "parser/cmdoptions.l"
return tok::H_BIF_POWNER;
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 224 "parser/cmdoptions.l"
return tok::H_BIF_PRESIGN;
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 225 "parser/cmdoptions.l"
return tok::H_BIF_UDF;
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 226 "parser/cmdoptions.l"
return tok::H_BIF_XIP;
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 227 "parser/cmdoptions.l"
return tok::H_BIF_ALIGN;
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 228 "parser/cmdoptions.l"
return tok::H_BIF_OFFSET;
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 229 "parser/cmdoptions.l"
return tok::H_BIF_RES;
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 230 "parser/cmdoptions.l"
return tok::H_BIF_LOAD;
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 231 "parser/cmdoptions.l"
return tok::H_BIF_STARTUP;
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 232 "parser/cmdoptions.l"
return tok::H_BIF_KEYSRCENCR;
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 233 "parser/cmdoptions.l"
return tok::H_BIF_FSBLCFG;
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 234 "parser/cmdoptions.l"
return tok::H_BIF_BOOTDEV;
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 235 "parser/cmdoptions.l"
return tok::H_BIF_DESTCPU;
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 236 "parser/cmdoptions.l"
return tok::H_BIF_DESTDEV;
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 237 "parser/cmdoptions.l"
return tok::H_BIF_EL;
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 238 "parser/cmdoptions.l"
return tok::H_BIF_TZ;
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 239 "parser/cmdoptions.l"
return tok::H_BIF_AUTHPARAM;
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 240 "parser/cmdoptions.l"
return tok::H_BIF_BHKEY;
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 241 "parser/cmdoptions.l"
return tok::H_BIF_PFW;
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 242 "parser/cmdoptions.l"
return tok::H_BIF_BLOCKS;
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 243 "parser/cmdoptions.l"
return tok::H_BIF_BHIV;
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 244 "parser/cmdoptions.l"
return tok::H_BIF_METAL;
	YY_BREAK
case 183:
YY_RULE_SETUP
#line 245 "parser/cmdoptions.l"
return tok::H_BIF_ELYHNDOFF;
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 246 "parser/cmdoptions.l"
return tok::H_BIF_HIVEC;
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 247 "parser/cmdoptions.l"
return tok::H_BIF_BHSIGN;
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 248 "parser/cmdoptions.l"
return tok::H_SPLIT;
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 249 "parser/cmdoptions.l"
return tok::H_BIF_BOOTVEC;
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 250 "parser/cmdoptions.l"
return tok::H_BIF_PUFDATA;
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 251 "parser/cmdoptions.l"
return tok::H_DPACM_ENABLE;
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 252 "parser/cmdoptions.l"
return tok::H_BIF_USERKEYS;
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 253 "parser/cmdoptions.l"
return tok::HVN_BIF_PCR;
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 254 "parser/cmdoptions.l"
return tok::HVN_BIF_PCR_MINDEX;
	YY_BREAK
case 193:
YY_RULE_SETUP
#line 255 "parser/cmdoptions.l"
return tok::HV_BIF_IMAGESTORE;
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 259 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);         return tok::HEXSTRING;
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 260 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);  return tok::IDENTIFIER;
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 261 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext);    return tok::FILENAME;
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 262 "parser/cmdoptions.l"
yylval->cstring=strdup(yytext+1); yylval->cstring[strlen(yytext)-2]=0; return tok::QFILENAME;
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 265 "parser/cmdoptions.l"
yylloc->step ();
	YY_BREAK
case 199:
/* rule 199 can match eol */
YY_RULE_SETUP
#line 266 "parser/cmdoptions.l"
yylloc->lines (yyleng); yylloc->step ();
	YY_BREAK
case 200:
YY_RULE_SETUP
#line 267 "parser/cmdoptions.l"
LOG_ERROR("Unknown option on command line: %s\n",yytext);
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 268 "parser/cmdoptions.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2514 "bisonflex/cmdoptions.yy.cpp"
case YY_STATE_EOF(INITIAL):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::yyFlexLexer( std::istream* arg_yyin, std::ostream* arg_yyout )
{
	yyin = arg_yyin;
	yyout = arg_yyout;
	yy_c_buf_p = 0;
	yy_init = 0;
	yy_start = 0;
	yy_flex_debug = 0;
	yylineno = 1;	// this will only get updated if %option yylineno

	yy_did_buffer_switch_on_eof = 0;

	yy_looking_for_trail_begin = 0;
	yy_more_flag = 0;
	yy_more_len = 0;
	yy_more_offset = yy_prev_more_offset = 0;

	yy_start_stack_ptr = yy_start_stack_depth = 0;
	yy_start_stack = NULL;

	yy_buffer_stack = 0;
	yy_buffer_stack_top = 0;
	yy_buffer_stack_max = 0;

	yy_state_buf = 0;

}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
yyFlexLexer::~yyFlexLexer()
{
	delete [] yy_state_buf;
	cmdoptionsfree(yy_start_stack  );
	yy_delete_buffer( YY_CURRENT_BUFFER );
	cmdoptionsfree(yy_buffer_stack  );
}

/* The contents of this function are C++ specific, so the () macro is not used.
 */
void yyFlexLexer::switch_streams( std::istream* new_in, std::ostream* new_out )
{
	if ( new_in )
		{
		yy_delete_buffer( YY_CURRENT_BUFFER );
		yy_switch_to_buffer( yy_create_buffer( new_in, YY_BUF_SIZE  ) );
		}

	if ( new_out )
		yyout = new_out;
}

#ifdef YY_INTERACTIVE
int yyFlexLexer::LexerInput( char* buf, int /* max_size */ )
#else
int yyFlexLexer::LexerInput( char* buf, int max_size )
#endif
{
	if ( yyin->eof() || yyin->fail() )
		return 0;

#ifdef YY_INTERACTIVE
	yyin->get( buf[0] );

	if ( yyin->eof() )
		return 0;

	if ( yyin->bad() )
		return -1;

	return 1;

#else
	(void) yyin->read( buf, max_size );

	if ( yyin->bad() )
		return -1;
	else
		return yyin->gcount();
#endif
}

void yyFlexLexer::LexerOutput( const char* buf, int size )
{
	(void) yyout->write( buf, size );
}
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
int yyFlexLexer::yy_get_next_buffer()
/* %endif */
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					cmdoptionsrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) cmdoptionsrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */

/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_get_previous_state()
/* %endif */
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 1140 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    yy_state_type yyFlexLexer::yy_try_NUL_trans( yy_state_type yy_current_state )
/* %endif */
{
	register int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 1140 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 1139);

	return yy_is_jam ? 0 : yy_current_state;
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyunput( int c, register char* yy_bp)
/* %endif */
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yyinput()
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */

	return c;
}
/* %if-c-only */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yyrestart( std::istream* input_file )
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_switch_to_buffer( YY_BUFFER_STATE new_buffer )
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_load_buffer_state()
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    YY_BUFFER_STATE yyFlexLexer::yy_create_buffer( std::istream* file, int size )
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) cmdoptionsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) cmdoptionsalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_delete_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		cmdoptionsfree((void *) b->yy_ch_buf  );

	cmdoptionsfree((void *) b  );
}

/* %if-c-only */
/* %endif */

/* %if-c++-only */

extern "C" int isatty (int );

/* %endif */

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_init_buffer( YY_BUFFER_STATE b, std::istream* file )
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */
/* %endif */
/* %if-c++-only */
	b->yy_is_interactive = 0;
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_flush_buffer( YY_BUFFER_STATE b )
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypush_buffer_state (YY_BUFFER_STATE new_buffer)
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yypop_buffer_state (void)
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::yyensure_buffer_stack(void)
/* %endif */
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmdoptionsalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)cmdoptionsrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_push_state( int new_state )
/* %endif */
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) cmdoptionsalloc(new_size  );

		else
			(yy_start_stack) = (int *) cmdoptionsrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    void yyFlexLexer::yy_pop_state()
/* %endif */
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

/* %if-c-only */
/* %endif */
/* %if-c++-only */
    int yyFlexLexer::yy_top_state()
/* %endif */
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
/* %endif */
/* %if-c++-only */
void yyFlexLexer::LexerError( yyconst char msg[] )
{
    	std::cerr << msg << std::endl;
	exit( YY_EXIT_FAILURE );
}
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* %if-reentrant */
/* %endif */
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *cmdoptionsalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *cmdoptionsrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void cmdoptionsfree (void * ptr )
{
	free( (char *) ptr );	/* see cmdoptionsrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 268 "parser/cmdoptions.l"




void CO::FlexScanner::comment()
{
    char c, c1;
    loop:
        while ((c = yyinput()) != '*' && c != 0) 
        {
            // putchar(c);
        }

    if ((c1 = yyinput()) != '/' && c != 0)
    {
        unput(c1);
        goto loop;
    }
}

